@@ -12,7 +12,7 @@ use Email::MIME;
 use Email::MIME::CreateHTML;
 use Email::Sender::Simple 'sendmail';
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub new {
     my $self = shift;
@@ -142,7 +142,7 @@ Email::Mailer - Multi-purpose emailer for HTML, auto-text, attachments, and temp
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Email-Mailer.svg)](https://travis-ci.org/gryphonshafer/Email-Mailer)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Email-Mailer/badge.png)](https://coveralls.io/r/gryphonshafer/Email-Mailer)
@@ -244,7 +244,7 @@ version 1.03
         process => sub {
             my ( $template, $data ) = @_;
             my $content;
-            $tt->process( $template, $data, \$content );
+            $tt->process( \$template, $data, \$content );
             return $content;
         },
     );
@@ -409,7 +409,7 @@ template text and a hashref of the data for the message.
         process => sub {
             my ( $template, $data ) = @_;
             my $content;
-            $tt->process( $template, $data, \$content );
+            $tt->process( \$template, $data, \$content );
             return $content;
         },
     );
